# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/transport/generated/sdk/v1/processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/transport/generated/sdk/v1/processor.proto',
  package='grebbleFlow.sdk.v1',
  syntax='proto3',
  serialized_options=b'Z<gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/sdk/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7grebble_flow/transport/generated/sdk/v1/processor.proto\x12\x12grebbleFlow.sdk.v1\"J\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04hint\x18\x03 \x01(\t\x12\x12\n\nfield_type\x18\x04 \x01(\t\"\x1c\n\x0cRelationDesc\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa1\x01\n\x04\x44\x65sc\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x31\n\nparameters\x18\x04 \x03(\x0b\x32\x1d.grebbleFlow.sdk.v1.Parameter\x12\x33\n\trelations\x18\x05 \x03(\x0b\x32 .grebbleFlow.sdk.v1.RelationDesc\"(\n\x07Package\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"a\n\tProcessor\x12,\n\x07package\x18\x01 \x01(\x0b\x32\x1b.grebbleFlow.sdk.v1.Package\x12&\n\x04\x64\x65sc\x18\x02 \x01(\x0b\x32\x18.grebbleFlow.sdk.v1.Desc\"\x13\n\x11InitProcessorsReq\"F\n\x11InitProcessorsRes\x12\x31\n\nprocessors\x18\x01 \x03(\x0b\x32\x1d.grebbleFlow.sdk.v1.Processor\"c\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x01(\x0c\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\"V\n\x0fTransferMessage\x12,\n\x07message\x18\x01 \x01(\x0b\x32\x1b.grebbleFlow.sdk.v1.Message\x12\x15\n\rrelation_name\x18\x02 \x01(\t\"M\n\x0cOnTriggerRes\x12=\n\x10transfer_message\x18\x01 \x01(\x0b\x32#.grebbleFlow.sdk.v1.TransferMessage\"a\n\x0cOnTriggerReq\x12\x11\n\tflow_name\x18\x01 \x01(\t\x12,\n\x07Message\x18\x02 \x01(\x0b\x32\x1b.grebbleFlow.sdk.v1.Message\x12\x10\n\x08settings\x18\x03 \x01(\x0c\x32\xc9\x01\n\x10ProcessorService\x12`\n\x0eInitProcessors\x12%.grebbleFlow.sdk.v1.InitProcessorsReq\x1a%.grebbleFlow.sdk.v1.InitProcessorsRes\"\x00\x12S\n\tOnTrigger\x12 .grebbleFlow.sdk.v1.OnTriggerReq\x1a .grebbleFlow.sdk.v1.OnTriggerRes\"\x00\x30\x01\x42>Z<gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/sdk/v1b\x06proto3'
)




_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='grebbleFlow.sdk.v1.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.sdk.v1.Parameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='grebbleFlow.sdk.v1.Parameter.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='grebbleFlow.sdk.v1.Parameter.hint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_type', full_name='grebbleFlow.sdk.v1.Parameter.field_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=153,
)


_RELATIONDESC = _descriptor.Descriptor(
  name='RelationDesc',
  full_name='grebbleFlow.sdk.v1.RelationDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.sdk.v1.RelationDesc.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=183,
)


_DESC = _descriptor.Descriptor(
  name='Desc',
  full_name='grebbleFlow.sdk.v1.Desc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='grebbleFlow.sdk.v1.Desc.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='grebbleFlow.sdk.v1.Desc.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='grebbleFlow.sdk.v1.Desc.group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='grebbleFlow.sdk.v1.Desc.parameters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relations', full_name='grebbleFlow.sdk.v1.Desc.relations', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=347,
)


_PACKAGE = _descriptor.Descriptor(
  name='Package',
  full_name='grebbleFlow.sdk.v1.Package',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.sdk.v1.Package.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='grebbleFlow.sdk.v1.Package.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=389,
)


_PROCESSOR = _descriptor.Descriptor(
  name='Processor',
  full_name='grebbleFlow.sdk.v1.Processor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package', full_name='grebbleFlow.sdk.v1.Processor.package', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desc', full_name='grebbleFlow.sdk.v1.Processor.desc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=488,
)


_INITPROCESSORSREQ = _descriptor.Descriptor(
  name='InitProcessorsReq',
  full_name='grebbleFlow.sdk.v1.InitProcessorsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=509,
)


_INITPROCESSORSRES = _descriptor.Descriptor(
  name='InitProcessorsRes',
  full_name='grebbleFlow.sdk.v1.InitProcessorsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='grebbleFlow.sdk.v1.InitProcessorsRes.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=581,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='grebbleFlow.sdk.v1.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grebbleFlow.sdk.v1.Message.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='grebbleFlow.sdk.v1.Message.parent_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebbleFlow.sdk.v1.Message.attributes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='grebbleFlow.sdk.v1.Message.content_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='grebbleFlow.sdk.v1.Message.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=682,
)


_TRANSFERMESSAGE = _descriptor.Descriptor(
  name='TransferMessage',
  full_name='grebbleFlow.sdk.v1.TransferMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='grebbleFlow.sdk.v1.TransferMessage.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relation_name', full_name='grebbleFlow.sdk.v1.TransferMessage.relation_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=770,
)


_ONTRIGGERRES = _descriptor.Descriptor(
  name='OnTriggerRes',
  full_name='grebbleFlow.sdk.v1.OnTriggerRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_message', full_name='grebbleFlow.sdk.v1.OnTriggerRes.transfer_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=772,
  serialized_end=849,
)


_ONTRIGGERREQ = _descriptor.Descriptor(
  name='OnTriggerReq',
  full_name='grebbleFlow.sdk.v1.OnTriggerReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_name', full_name='grebbleFlow.sdk.v1.OnTriggerReq.flow_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Message', full_name='grebbleFlow.sdk.v1.OnTriggerReq.Message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='grebbleFlow.sdk.v1.OnTriggerReq.settings', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=948,
)

_DESC.fields_by_name['parameters'].message_type = _PARAMETER
_DESC.fields_by_name['relations'].message_type = _RELATIONDESC
_PROCESSOR.fields_by_name['package'].message_type = _PACKAGE
_PROCESSOR.fields_by_name['desc'].message_type = _DESC
_INITPROCESSORSRES.fields_by_name['processors'].message_type = _PROCESSOR
_TRANSFERMESSAGE.fields_by_name['message'].message_type = _MESSAGE
_ONTRIGGERRES.fields_by_name['transfer_message'].message_type = _TRANSFERMESSAGE
_ONTRIGGERREQ.fields_by_name['Message'].message_type = _MESSAGE
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['RelationDesc'] = _RELATIONDESC
DESCRIPTOR.message_types_by_name['Desc'] = _DESC
DESCRIPTOR.message_types_by_name['Package'] = _PACKAGE
DESCRIPTOR.message_types_by_name['Processor'] = _PROCESSOR
DESCRIPTOR.message_types_by_name['InitProcessorsReq'] = _INITPROCESSORSREQ
DESCRIPTOR.message_types_by_name['InitProcessorsRes'] = _INITPROCESSORSRES
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['TransferMessage'] = _TRANSFERMESSAGE
DESCRIPTOR.message_types_by_name['OnTriggerRes'] = _ONTRIGGERRES
DESCRIPTOR.message_types_by_name['OnTriggerReq'] = _ONTRIGGERREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

RelationDesc = _reflection.GeneratedProtocolMessageType('RelationDesc', (_message.Message,), {
  'DESCRIPTOR' : _RELATIONDESC,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.RelationDesc)
  })
_sym_db.RegisterMessage(RelationDesc)

Desc = _reflection.GeneratedProtocolMessageType('Desc', (_message.Message,), {
  'DESCRIPTOR' : _DESC,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Desc)
  })
_sym_db.RegisterMessage(Desc)

Package = _reflection.GeneratedProtocolMessageType('Package', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGE,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Package)
  })
_sym_db.RegisterMessage(Package)

Processor = _reflection.GeneratedProtocolMessageType('Processor', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSOR,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Processor)
  })
_sym_db.RegisterMessage(Processor)

InitProcessorsReq = _reflection.GeneratedProtocolMessageType('InitProcessorsReq', (_message.Message,), {
  'DESCRIPTOR' : _INITPROCESSORSREQ,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.InitProcessorsReq)
  })
_sym_db.RegisterMessage(InitProcessorsReq)

InitProcessorsRes = _reflection.GeneratedProtocolMessageType('InitProcessorsRes', (_message.Message,), {
  'DESCRIPTOR' : _INITPROCESSORSRES,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.InitProcessorsRes)
  })
_sym_db.RegisterMessage(InitProcessorsRes)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.Message)
  })
_sym_db.RegisterMessage(Message)

TransferMessage = _reflection.GeneratedProtocolMessageType('TransferMessage', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERMESSAGE,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.TransferMessage)
  })
_sym_db.RegisterMessage(TransferMessage)

OnTriggerRes = _reflection.GeneratedProtocolMessageType('OnTriggerRes', (_message.Message,), {
  'DESCRIPTOR' : _ONTRIGGERRES,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.OnTriggerRes)
  })
_sym_db.RegisterMessage(OnTriggerRes)

OnTriggerReq = _reflection.GeneratedProtocolMessageType('OnTriggerReq', (_message.Message,), {
  'DESCRIPTOR' : _ONTRIGGERREQ,
  '__module__' : 'grebble_flow.transport.generated.sdk.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.sdk.v1.OnTriggerReq)
  })
_sym_db.RegisterMessage(OnTriggerReq)


DESCRIPTOR._options = None

_PROCESSORSERVICE = _descriptor.ServiceDescriptor(
  name='ProcessorService',
  full_name='grebbleFlow.sdk.v1.ProcessorService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=951,
  serialized_end=1152,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitProcessors',
    full_name='grebbleFlow.sdk.v1.ProcessorService.InitProcessors',
    index=0,
    containing_service=None,
    input_type=_INITPROCESSORSREQ,
    output_type=_INITPROCESSORSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnTrigger',
    full_name='grebbleFlow.sdk.v1.ProcessorService.OnTrigger',
    index=1,
    containing_service=None,
    input_type=_ONTRIGGERREQ,
    output_type=_ONTRIGGERRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSORSERVICE)

DESCRIPTOR.services_by_name['ProcessorService'] = _PROCESSORSERVICE

# @@protoc_insertion_point(module_scope)
